Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
lufa-rs
This crate provides Rust raw bindings for the LUFA (Lightweight USB Framework for AVRs) library. It also contains some utility functions and macros to easily create HID (Human Interface Device) applications.
Installation
Add to your Cargo.toml file:
[]
= "0.1"
Usage
LUFA needs some environment variables to be set for the build process. You can set them in your .cargo/config file:
[]
="16000000"
="ARCH_AVR8"
="BOARD_USBKEY"
="atmega32u4"
= { = ".", = true }
A LUFAConfig.h file needs to be present in the LUFA_CONFIG_PATH directory. See LUFA devices examples or rust-keyboard to create one.
Then you can use the library in your project:
use asm;
use ;
Some extern functions must be implemented for the library to work correctly. See any LUFA example for details.
Examples
LUFA demos can be found in the LUFA repository.
See the rust-keyboard repository for usage cases. The library is used here
Contribution
Contributions are welcome! Open an issue or a pull request.
License
This project is licensed under the MIT License.